<?php

use BitBadger\Documents\SQLite\Custom;
use BitBadger\Documents\SQLite\Results;
use FeedReaderCentral\Data;

require __DIR__ . '/../cli-start.php';

cli_title('SEARCH MAINTENANCE');

if ($argc < 2) display_help();

switch ($argv[1]) {
    case 'rebuild':
        rebuild_index();
        break;
    default:
        printfn('Unrecognized option "%s"', $argv[1]);
        display_help();
}


/**
 * Display the options for this utility and exit
 */
function display_help(): never
{
    printfn('Options:');
    printfn(' - rebuild');
    printfn('     Rebuilds search index');
    exit(0);
}

/**
 * Rebuild the search index, creating it if it does not already exist
 */
function rebuild_index(): void
{
    $db = Data::getConnection();

    try {
        $hasIndex = Custom::scalar("SELECT COUNT(*) FROM sqlite_master WHERE name = 'item_ai'", [],
            Results::toCount(...), $db);
        if ($hasIndex == 0) {
            printfn('Creating search index....');
            Data::createSearchIndex($db);
        }
        printfn('Rebuilding search index...');
        Custom::nonQuery("INSERT INTO item_search (item_search) VALUES ('rebuild')", [], $db);
//        $db->exec("INSERT INTO item_search (item_search) VALUES ('rebuild')");
        printfn(PHP_EOL . 'Search index rebuilt');
    } finally {
        $db->close();
    }
}
